@@ -25,6 +25,7 @@ from . import (
     secondary_findings_genes,
     mito_trna,
     mtdb,
+    clingen_dosage,
 )
 
 __all__ = (
@@ -55,4 +56,5 @@ __all__ = (
     "secondary_findings_genes",
     "mito_trna",
     "mtdb",
+    "clingen_dosage",
 )
