@@ -17,7 +17,7 @@ register(
         lambda x: assoc(x, "is_gene_annotation", True),
         lambda x: assoc(x, __TYPE__, DocType.SECONDARY_FINDINGS_GENES.value),
         lambda x: assoc(x, "gene", turn_gene_to_list(x)),
-        name_mapping(NAME_MAPPING)
+        name_mapping(NAME_MAPPING),
     ),
 )
 
